package consume

import (
	"applet/app/utils/logx"
	consumeMd "applet/consume/md"
	"time"
)

var (
	jobs = map[string]func(consumeMd.MqQueue){}
)

func Init() {
	// 初始化任务列表
	initConsumes()
}

// 增加消费任务队列
func initConsumes() {
	jobs[consumeMd.EggSlowAutoUpLvConsume] = EggSlowAutoUpLvConsume             //缓慢 自动升级
	jobs[consumeMd.EggEnergyUserActivityConsume] = EggEnergyUserActivityConsume //监听 自动升级
	jobs[consumeMd.EggCanalUserConsume] = EggCanalUserConsume                   //监听 自动升级

	jobs[consumeMd.AliyunSmsRecordFunName] = AliyunSmsRecordConsume //阿里云短信
	jobs[consumeMd.JpushRecordFunName] = JpushRecordConsume         //极光推送
	jobs[consumeMd.UserDeleteFunName] = UserDeleteConsume           // 用户注销处理

	jobs[consumeMd.EggEnergyNewUserRegisterDataFunName] = EggEnergyNewUserRegisterDataConsume       // 新用户注册
	jobs[consumeMd.IMEggEnergyBatchSendMessageDataFunName] = IMEggEnergyBatchSendMessageDataConsume // 批量发送信息
	jobs[consumeMd.IMEggEnergyDelFriendCircleDataFunName] = IMEggEnergyDelFriendCircleDataConsume   // 删除朋友圈
	jobs[consumeMd.EggFinWithdrawApplyDataConsumeFunName] = EggFinWithdrawApplyDataConsume          // 提现

	jobs[consumeMd.EggEnergyDealUserECPMFunName] = EggEnergyDealUserECPMConsume                   // 处理给用户Ecpm值
	jobs[consumeMd.EggCanalInviteUserNumsFunName] = EggCanalInviteUserNumsConsume                 // 处理拉新人数
	jobs[consumeMd.EggCanalViolateNumsFunName] = EggCanalViolateNumsConsume                       // 处理违规次数
	jobs[consumeMd.IMEggEnergySendRedPackageFunName] = IMEggEnergySendRedPackageConsume           // 处理用户发送红包次数
	jobs[consumeMd.VideoRewardFunName] = VideoRewardConsume                                       // 短视频奖励
	jobs[consumeMd.PlayletRewardFunName] = PlayletRewardConsume                                   // 短剧奖励
	jobs[consumeMd.EggCanalPersonAddActivityValueFunName] = EggCanalPersonAddActivityValueConsume // 用户活跃积分变更时更新es

	jobs[consumeMd.EggEnergyDealPlatformRevenueDataFunName] = EggEnergyDealPlatformRevenueDataConsume // 平台营收
	jobs[consumeMd.EggEnergyDealFundDataFunName] = EggEnergyDealFundDataConsume                       // 资金数据
	jobs[consumeMd.EggEnergyDealUserVirtualCoinDataFunName] = EggEnergyDealUserVirtualCoinDataConsume // 视频奖励给相应团队发放积分
	jobs[consumeMd.EggRecordActiveDataFunName] = EggRecordActiveDataConsume                           // 用户签到后更新活跃数据
	jobs[consumeMd.EggEnergyAutoScoreDataFunName] = EggEnergyAutoScoreConsume                         // 自动打分

	jobs[consumeMd.PublicPlatoonUserRelationCommissionConsumeFunName] = AddPublicPlatoonUserRelationCommissionConsume
	jobs[consumeMd.EggEnergyStartLevelDividendFunName] = EggEnergyStartLevelDividendConsume
	jobs[consumeMd.EggEnergySettlementPublicGiveActivityCoinFunName] = EggEnergySettlementPublicGiveActivityCoinConsume
	jobs[consumeMd.EggEnergyStartExchangeGreenEnergyFunName] = EggEnergyStartExchangeGreenEnergyConsume
	jobs[consumeMd.EggEnergyAutoExchangeGreenEnergyFunName] = EggEnergyAutoExchangeGreenEnergyConsume
	jobs[consumeMd.EggEnergyAutoScoreDataFunName] = EggEnergyAutoScoreConsume // 自动打分

}

func Run() {
	for _, v := range consumeMd.RabbitMqQueueKeyList {
		if _, ok := jobs[v.ConsumeFunName]; ok {
			go doConsume(v.ConsumeFunName, *v)()
		}
	}
}

func doConsume(fnName string, queue consumeMd.MqQueue) func() {
	return func() {
		begin := time.Now().Local()
		jobs[fnName](queue)
		end := time.Now().Local()
		logx.Infof(
			"[%s] AutoConsume started at <%s>, ended at <%s> duration <%s>",
			fnName,
			begin.Format("2006-01-02 15:04:05.000"),
			end.Format("2006-01-02 15:04:05.000"),
			time.Duration(end.UnixNano()-begin.UnixNano()).String(),
		)
	}
}
